const API_URL = 'https://shmoolptc.com/budget-system/backend/api';

async function saveBudget(budgetData) {
  try {
    const response = await fetch(`${API_URL}/budget/create.php`, {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json'
      },
      body: JSON.stringify(budgetData)
    });

    const result = await response.json();
    if (response.ok) {
      showNotification('تم حفظ الميزانية بنجاح');
      return result;
    } else {
      throw new Error(result.message);
    }
  } catch (error) {
    showNotification('حدث خطأ أثناء حفظ الميزانية', 'error');
    console.error('Error:', error);
  }
}

async function calculateBudget() {
  if (!validateInputs()) {
    showNotification('الرجاء ملء جميع الحقول المطلوبة', 'error');
    return;
  }

  const budgetData = {
    company_id: 1,
    quarter: parseInt(document.getElementById('quarter').value),
    year: parseInt(document.getElementById('year').value),
    sales: parseFloat(document.getElementById('sales').value) || 0,
    other_income: parseFloat(document.getElementById('otherIncome').value) || 0,
    cost_of_sales: parseFloat(document.getElementById('costOfSales').value) || 0,
    admin_expenses: parseFloat(document.getElementById('adminExpenses').value) || 0,
    other_expenses: parseFloat(document.getElementById('otherExpenses').value) || 0,
    status: 'draft'
  };

  const savedBudget = await saveBudget(budgetData);
  if (savedBudget) {
    displayResults(budgetData);
  }
}

function validateInputs() {
  const companyName = document.getElementById('companyName').value;
  return companyName.trim() !== '';
}

function displayResults(budgetData) {
  // حساب القيم المختلفة
  const totalIncome = budgetData.sales + budgetData.other_income;
  const totalExpenses = budgetData.cost_of_sales + budgetData.admin_expenses + budgetData.other_expenses;
  const netIncome = totalIncome - totalExpenses;
  const zakat = netIncome > 0 ? netIncome * 0.025 : 0;
  const netAfterZakat = netIncome - zakat;

  // عرض النتائج
  const resultsContent = `
        <h3>ملخص الميزانية الربعية</h3>
        <div class="result-item">
            <span>اسم الشركة</span>
            <strong>${budgetData.company_name || 'غير محدد'}</strong>
        </div>
        <div class="result-item">
            <span>الفترة المالية</span>
            <strong>الربع ${budgetData.quarter} - ${budgetData.year}</strong>
        </div>
        <div class="result-item">
            <span>إجمالي المبيعات</span>
            <strong>${formatCurrency(budgetData.sales)}</strong>
        </div>
        <div class="result-item">
            <span>إجمالي الإيرادات</span>
            <strong>${formatCurrency(totalIncome)}</strong>
        </div>
        <div class="result-item">
            <span>إجمالي المصروفات</span>
            <strong>${formatCurrency(totalExpenses)}</strong>
        </div>
        <div class="result-item">
            <span>صافي الدخل قبل الزكاة</span>
            <strong class="${netIncome >= 0 ? 'total-positive' : 'total-negative'}">
                ${formatCurrency(netIncome)}
            </strong>
        </div>
        <div class="result-item">
            <span>الزكاة</span>
            <strong>${formatCurrency(zakat)}</strong>
        </div>
        <div class="result-item">
            <span>صافي الدخل بعد الزكاة</span>
            <strong class="${netAfterZakat >= 0 ? 'total-positive' : 'total-negative'}">
                ${formatCurrency(netAfterZakat)}
            </strong>
        </div>
    `;

  document.getElementById('resultsContent').innerHTML = resultsContent;
  document.getElementById('results').style.display = 'block';
  createChart(totalIncome, totalExpenses, netAfterZakat);
}

function createChart(income, expenses, net) {
  const ctx = document.getElementById('budgetChart').getContext('2d');
  new Chart(ctx, {
    type: 'bar',
    data: {
      labels: ['الإيرادات', 'المصروفات', 'صافي الدخل'],
      datasets: [{
        label: 'الميزانية الربعية',
        data: [income, expenses, net],
        backgroundColor: [
                    'rgba(52, 152, 219, 0.5)',
                    'rgba(231, 76, 60, 0.5)',
                    'rgba(46, 204, 113, 0.5)'
                ],
        borderColor: [
                    'rgba(52, 152, 219, 1)',
                    'rgba(231, 76, 60, 1)',
                    'rgba(46, 204, 113, 1)'
                ],
        borderWidth: 1
            }]
    },
    options: {
      responsive: true,
      scales: {
        y: {
          beginAtZero: true
        }
      },
      plugins: {
        legend: {
          display: false
        }
      }
    }
  });
}

function resetForm() {
  document.getElementById('budgetForm').reset();
  document.getElementById('results').style.display = 'none';
}

function showNotification(message, type = 'success') {
  const notification = document.getElementById('notification');
  const toastBody = notification.querySelector('.toast-body');
  const toastBootstrap = bootstrap.Toast.getOrCreateInstance(notification);

  toastBody.textContent = message;

  if (type === 'error') {
    notification.classList.remove('bg-success');
    notification.classList.add('bg-danger');
  } else {
    notification.classList.remove('bg-danger');
    notification.classList.add('bg-success');
  }

  toastBootstrap.show();
}

function formatCurrency(amount) {
  return new Intl.NumberFormat('ar-SA', {
    style: 'currency',
    currency: 'SAR'
  }).format(amount);
}

document.querySelectorAll('input[type="number"]').forEach(input => {
  input.addEventListener('input', function() {
    if (this.value < 0) this.value = 0;
  });
});